function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import React from 'react';
import { useToggleState } from '@react-stately/toggle';
import { StyleSheet, Switch as RNSwitch } from 'react-native';
import styled from 'styled-components/native';
import isNil from 'lodash/isNil';
import { useToken, useThemeProps } from '../../../hooks';
import { border, color, flexbox, layout, space, position } from 'styled-system';
import { customBorder, customBackground, customOutline, customLayout, customExtra, customShadow, customPosition } from '../../../utils/customProps';
import { useSwitch, AriaInputWrapper } from 'react-native-aria';
const StyledNBSwitch = styled(RNSwitch)(color, space, layout, flexbox, border, position, customPosition, customBorder, customBackground, customOutline, customShadow, customExtra, customLayout);

const Switch = ({
  style,
  onToggle,
  isDisabled,
  isInvalid,
  iosBgColor,
  isChecked,
  defaultIsChecked,
  accessibilityLabel,
  accessibilityHint,
  onColor,
  offColor,
  ...props
}, ref) => {
  var _newProps$transform;

  const state = useToggleState({
    defaultSelected: !isNil(defaultIsChecked) ? defaultIsChecked : false
  });
  const borderColorInvalid = useToken('colors', 'danger.600');
  const checked = !isNil(isChecked) ? isChecked : state.isSelected;
  const newProps = useThemeProps('Switch', { ...props,
    checked,
    onColor,
    offColor
  });
  const inValidPropFactors = {
    borderWidth: 1,
    borderRadius: 16,
    borderColor: borderColorInvalid
  };
  let computedStyle = StyleSheet.flatten([style, {
    transform: (_newProps$transform = newProps.transform) !== null && _newProps$transform !== void 0 ? _newProps$transform : undefined
  }, isInvalid ? inValidPropFactors : {}]);
  const inputRef = React.useRef(null);
  let {
    inputProps
  } = useSwitch({
    'aria-label': accessibilityLabel,
    'aria-describedby': accessibilityHint,
    isDisabled
  }, state, inputRef);
  return /*#__PURE__*/React.createElement(AriaInputWrapper, _extends({}, inputProps, {
    ref: inputRef
  }), /*#__PURE__*/React.createElement(StyledNBSwitch, _extends({}, newProps, {
    disabled: isDisabled,
    ios_backgroundColor: iosBgColor,
    onValueChange: onToggle ? onToggle : state.toggle,
    value: checked,
    style: computedStyle,
    ref: ref,
    opacity: isDisabled ? 0.4 : 1
  })));
};

export default /*#__PURE__*/React.memo( /*#__PURE__*/React.forwardRef(Switch));
//# sourceMappingURL=index.js.map